==> vue-components-1.5.1.tgz: package/lib/vite/regiondev/index.rd.js <==
import { regionComponents as e } from "./components.rd.js";
import { ComponentRoots as s, RegionComponentsEnum as m } from "./components.rd.js";
const o = "@regiondev/vue-components/lib", i = {
  from: o,
  names: e
}, v = {
  "@regiondev/vue-utils": ["pt"],
  [o]: e
}, t = [
  "@regiondev/vue-components/lib/alert",
  "@regiondev/vue-components/lib/avatar",
  "@regiondev/vue-components/lib/badge",
  "@regiondev/vue-components/lib/blurLoader",
  "@regiondev/vue-components/lib/buttons",
  "@regiondev/vue-components/lib/collapse",
  "@regiondev/vue-components/lib/cropper",
  "@regiondev/vue-components/lib/datePicker",
  "@regiondev/vue-components/lib/drawer",
  "@regiondev/vue-components/lib/dropdown",
  "@regiondev/vue-components/lib/fileUpload",
  "@regiondev/vue-components/lib/form",
  "@regiondev/vue-components/lib/input",
  "@regiondev/vue-components/lib/jsonTree",
  "@regiondev/vue-components/lib/message",
  "@regiondev/vue-components/lib/modals",
  "@regiondev/vue-components/lib/pickList",
  "@regiondev/vue-components/lib/popConfirm",
  "@regiondev/vue-components/lib/popover",
  "@regiondev/vue-components/lib/rating",
  "@regiondev/vue-components/lib/select",
  "@regiondev/vue-components/lib/spinners",
  "@regiondev/vue-components/lib/toggle",
  "@regiondev/vue-components/lib/tooltip",
  "@regiondev/vue-components/lib/ui"
];
export {
  i as AutoImportTypes,
  s as ComponentRoots,
  o as REGIONDEV_DIR,
  m as RegionComponentsEnum,
  t as optimizableDeps,
  e as regionComponents,
  v as regionDevUnpluginImport
};

==> vue-components-1.5.3.tgz: package/lib/vite/regiondev/index.rd.js <==
import { regionComponents as e } from "./components.rd.js";
import { ComponentRoots as s, RegionComponentsEnum as m } from "./components.rd.js";
const o = "@regiondev/vue-components/lib", i = {
  from: o,
  names: e
}, v = {
  "@regiondev/vue-utils": ["pt"],
  [o]: e
}, t = [
  "@regiondev/vue-components/lib/alert",
  "@regiondev/vue-components/lib/avatar",
  "@regiondev/vue-components/lib/badge",
  "@regiondev/vue-components/lib/blurLoader",
  "@regiondev/vue-components/lib/buttons",
  "@regiondev/vue-components/lib/collapse",
  "@regiondev/vue-components/lib/cropper",
  "@regiondev/vue-components/lib/datePicker",
  "@regiondev/vue-components/lib/drawer",
  "@regiondev/vue-components/lib/dropdown",
  "@regiondev/vue-components/lib/fileUpload",
  "@regiondev/vue-components/lib/form",
  "@regiondev/vue-components/lib/input",
  "@regiondev/vue-components/lib/jsonTree",
  "@regiondev/vue-components/lib/message",
  "@regiondev/vue-components/lib/modals",
  "@regiondev/vue-components/lib/pickList",
  "@regiondev/vue-components/lib/popConfirm",
  "@regiondev/vue-components/lib/popover",
  "@regiondev/vue-components/lib/rating",
  "@regiondev/vue-components/lib/select",
  "@regiondev/vue-components/lib/spinners",
  "@regiondev/vue-components/lib/toggle",
  "@regiondev/vue-components/lib/tooltip",
  "@regiondev/vue-components/lib/ui/checks",
  "@regiondev/vue-components/lib/ui/steps",
  "@regiondev/vue-components/lib/ui/menu",
  "@regiondev/vue-components/lib/ui/radios"
];
export {
  i as AutoImportTypes,
  s as ComponentRoots,
  o as REGIONDEV_DIR,
  m as RegionComponentsEnum,
  t as optimizableDeps,
  e as regionComponents,
  v as regionDevUnpluginImport
};
